@@ -11,6 +11,13 @@ enum Command {
     Updating = 0x1e,
 }
 
+/// Represents an XQuery code identified by the database.
+///
+/// Database query is created out of an XQuery syntax string. The XQuery gets send to the database and associated with
+/// an ID. Once the query ID is assigned, the XQuery cannot be changed, but the client may bind arguments or context
+/// for it.
+///
+/// Once happy with the arguments bound or context set, the Query can be executed or analysed.
 pub struct Query<T> where T: DatabaseStream {
     id: String,
     connection: Connection<T>,
@@ -18,10 +25,11 @@ pub struct Query<T> where T: DatabaseStream {
 
 impl<T> Query<T> where T: DatabaseStream {
 
-    pub fn new(id: String, connection: Connection<T>) -> Self {
+    pub(crate) fn new(id: String, connection: Connection<T>) -> Self {
         Self { id, connection }
     }
 
+    /// Closes and unregisters the query with the specified id.
     pub fn close(&mut self) -> Result<&mut Self> {
         self.connection.send_cmd(Command::Close as u8)?;
         self.connection.send_arg(&mut self.id.as_bytes())?;
@@ -29,6 +37,7 @@ impl<T> Query<T> where T: DatabaseStream {
         Ok(self)
     }
 
+    /// Binds a value to a variable. The type will be ignored if the value is `None`.
     pub fn bind(&mut self, name: &str, value: Option<&str>, value_type: Option<&str>) -> Result<&mut Self> {
         self.connection.send_cmd(Command::Bind as u8)?;
         self.connection.send_arg(&mut self.id.as_bytes())?;
@@ -45,24 +54,28 @@ impl<T> Query<T> where T: DatabaseStream {
         Ok(self)
     }
 
+    /// Executes the query and returns the result as a single string.
     pub fn execute(&mut self) -> Result<String> {
         self.connection.send_cmd(Command::Execute as u8)?;
         self.connection.send_arg(&mut self.id.as_bytes())?;
         self.connection.get_response()
     }
 
+    /// Returns a string with query compilation and profiling info.
     pub fn info(&mut self) -> Result<String> {
         self.connection.send_cmd(Command::Info as u8)?;
         self.connection.send_arg(&mut self.id.as_bytes())?;
         self.connection.get_response()
     }
 
+    /// Returns a string with all query serialization parameters, which can e.g. be assigned to the SERIALIZER option.
     pub fn options(&mut self) -> Result<String> {
         self.connection.send_cmd(Command::Options as u8)?;
         self.connection.send_arg(&mut self.id.as_bytes())?;
         self.connection.get_response()
     }
 
+    /// Binds a value to the context. The type will be ignored if the value is `None`.
     pub fn context(&mut self, value: Option<&str>, value_type: Option<&str>) -> Result<&mut Self> {
         self.connection.send_cmd(Command::Context as u8)?;
         self.connection.send_arg(&mut self.id.as_bytes())?;
@@ -78,10 +91,16 @@ impl<T> Query<T> where T: DatabaseStream {
         Ok(self)
     }
 
-    pub fn updating(&mut self) -> Result<String> {
+    /// Checks if the query contains updating expressions.
+    pub fn updating(&mut self) -> Result<bool> {
         self.connection.send_cmd(Command::Updating as u8)?;
         self.connection.send_arg(&mut self.id.as_bytes())?;
-        self.connection.get_response()
+
+        match self.connection.get_response()?.as_str() {
+            "true" => Ok(true),
+            "false" => Ok(false),
+            other => panic!("Expected boolean string, got \"{}\"", other),
+        }
     }
 }
 
@@ -213,14 +232,13 @@ mod tests {
 
     #[test]
     fn test_query_runs_updating_command() {
-        let expected_response = "test_response";
-        let stream = MockStream::new(expected_response.to_owned());
+        let stream = MockStream::new("true".to_owned());
         let connection = Connection::new(stream);
 
         let mut query = Query::new("test".to_owned(), connection);
         let actual_response = query.updating().unwrap();
 
-        assert_eq!(expected_response, actual_response);
+        assert!(actual_response);
 
         let stream = query.into_inner().into_inner();
         let actual_buffer = stream.to_string();
@@ -229,6 +247,33 @@ mod tests {
         assert_eq!(expected_buffer, actual_buffer);
     }
 
+    #[test]
+    fn test_query_runs_non_updating_command() {
+        let stream = MockStream::new("false".to_owned());
+        let connection = Connection::new(stream);
+
+        let mut query = Query::new("test".to_owned(), connection);
+        let actual_response = query.updating().unwrap();
+
+        assert!(!actual_response);
+
+        let stream = query.into_inner().into_inner();
+        let actual_buffer = stream.to_string();
+        let expected_buffer = "\u{1e}test\u{0}".to_owned();
+
+        assert_eq!(expected_buffer, actual_buffer);
+    }
+
+    #[test]
+    #[should_panic]
+    fn test_query_panics_updating_command_response_is_not_bool() {
+        let stream = MockStream::new("test_response".to_owned());
+        let connection = Connection::new(stream);
+
+        let mut query = Query::new("test".to_owned(), connection);
+        let _ = query.updating().unwrap();
+    }
+
     #[test]
     fn test_query_fails_to_run_updating_command_with_failing_stream() {
         let connection = Connection::new(FailingStream);
